@@ -2,7 +2,6 @@
 #Corresponds to pulling a ranked report
 #This API method seems to be most complicated to return a valid result
 
-
 QueueRanked <- function(reportSuiteID, dateFrom, dateTo, metrics, elements, top="", startingWith="", segment_id="", selected="", currentData=""){
   
   #1.  Send API request to build report- QueueRanked
@@ -42,7 +41,8 @@ QueueRanked <- function(reportSuiteID, dateFrom, dateTo, metrics, elements, top=
      "metrics": [%s],
      "elements" : [%s],
      "segment_id": "%s",
-     "currentData": "%s"
+     "currentData": "%s",
+     "validate": true
     }
 }', reportSuiteID, dateFrom, dateTo, metrics_final, elements_list,segment_id, currentData)
   } else {
@@ -65,7 +65,8 @@ QueueRanked <- function(reportSuiteID, dateFrom, dateTo, metrics, elements, top=
      "metrics": [%s],
      "elements" : [%s],
      "segment_id": "%s",
-     "currentData": "%s"
+     "currentData": "%s",
+     "validate": true
     }
 }', reportSuiteID, dateFrom, dateTo, metrics_final, elements_list, segment_id, currentData)
     
@@ -132,6 +133,7 @@ QueueRanked <- function(reportSuiteID, dateFrom, dateTo, metrics, elements, top=
   
   counts <- lapply(data, "[[", "counts") # Just the "counts" column
   counts_df <- ldply(counts, quickdf) # counts as DF
+  counts_df <- as.data.frame(apply(counts_df, MARGIN=2, FUN= function(x) as.numeric(x))) #convert to numeric
   names(counts_df) <- metrics_requested
   
   return(cbind(rows_df, segment=segment_requested, counts_df)) #append rows info with counts, End JSON parsing for single element case 
@@ -148,7 +150,8 @@ QueueRanked <- function(reportSuiteID, dateFrom, dateTo, metrics, elements, top=
       names(inner_element) <- elements_requested[2]
   #Get metrics that go along with breakdown rows    
       inner_metrics <- ldply((data[[i]][["breakdown"]]), "[[", "counts")
-    names(inner_metrics) <- metrics[1:ncol(inner_metrics)]     
+      inner_metrics <- as.data.frame(apply(inner_metrics, MARGIN=2, FUN= function(x) as.numeric(x))) #convert to numeric
+      names(inner_metrics) <- metrics[1:ncol(inner_metrics)]     
   #Join all datasets together horizontally
       temp <- cbind(outer_element, inner_element, inner_metrics)
   #Append vertically to accumulator    
